@@ -3,5 +3,5 @@ try:
     from .toolbox import *
     from .resultviewer import *
     from .metrics import *
-except ImportError:
-    print("")
+except:
+    raise
